==> tine20-allinone_2020.08.8.tar.bz2: Sales/js/Sales-lang-ja_JP-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (Japan) (http://www.transifex.com/tine20/tine20/language/ja_JP/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ja_JP\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "CLEARED"
: ""

, "INVOICE"
: ""

, "Invoice Timesheet"
: ""

, "Customer, Customers"
: [
  ""

]
, "Core Data"
: ""

, "Accounting"
: ""

, "Miscellaneous"
: ""

, "Customer Number"
: ""

, "Name"
: ""

, "Name shorthand"
: ""

, "Web"
: ""

, "Description"
: ""

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "VAT No."
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "Discount (%)"
: ""

, "Delivery Addresses"
: ""

, "Billing Addresses"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Postbox"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""

]
, "Type"
: ""

, "Title"
: ""

, "Month"
: ""

, "Unit"
: ""

, "Quantity"
: ""

, "Offer, Offers"
: [
  ""

]
, "Order Confirmation, Order Confirmations"
: [
  ""

]
, "Number"
: ""

, "Product, Products"
: [
  ""

]
, "Contract, Contracts"
: [
  ""

]
, "Billing Interval"
: ""

, "Billing Point"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Invoice Item"
: ""

, "Piece"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Category"
: ""

, "Manufacturer"
: ""

, "Accountable"
: ""

, "GTIN"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Is active"
: ""

, "Invoice, Invoices"
: [
  ""

]
, "Invoice Number"
: ""

, "Address, Addresss"
: [
  ""

]
, "Date"
: ""

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Credit Term"
: ""

, "Cost Center, Cost Centers"
: [
  ""

]
, "Cleared"
: ""

, "Price Net"
: ""

, "Price Tax"
: ""

, "Price Gross"
: ""

, "Sales Tax"
: ""

, "Inventory Change"
: ""

, "Positions"
: ""

, "Reversal Invoice"
: ""

, "Supplier, Suppliers"
: [
  ""

]
, "Supplier Number"
: ""

, "Division, Divisions"
: [
  ""

]
, "Number Debit"
: ""

, "Products"
: ""

, "Billing Address"
: ""

, "Lead Cost Center"
: ""

, "Merge"
: ""

, "Responsible"
: ""

, "Partner"
: ""

, "Time Account"
: ""

, "Remark"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""

]
, "Approver"
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due at"
: ""

, "Payed at"
: ""

, "Payment_method"
: ""

, "Discount until"
: ""

, "Additional Price Gross"
: ""

, "Total Price"
: ""

, "without customer"
: ""

, "Export Records from these Positions"
: ""

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Enter description"
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Select customer"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Sales Tax (percent)"
: ""

, "automatically set..."
: ""

, "OK"
: ""

, "Loading..."
: ""

, "Euro (€)"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: ""

, "Enter description..."
: ""

, "Add New Product"
: ""

, "Product Number"
: ""

, "Select supplier"
: ""

, "Add New Cost Center"
: ""

, "Select invoice"
: ""

, "Either street or postbox is required!"
: ""

, "Only numbers are allowed!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "without external contact person"
: ""

, "without approver"
: ""

, "without supplier"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Due date"
: ""

, "Overdue date"
: ""

, "Dun date"
: ""

, "Method of payment"
: ""

, "without internal contact person"
: ""

, "Delivery Address"
: ""

, "Edit {0} \"{1}\""
: ""

, "Add new Billing Address"
: ""

, "Add new Delivery Address"
: ""

, "Apply postal address"
: ""

, "Add New Offer"
: ""

, "Add New Order Confirmation"
: ""

, "Interval"
: ""

, "begin"
: ""

, "end"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "Clipboard"
: ""

, "Add New Division"
: ""

, "without contract"
: ""

, "without order confirmation"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "without Cost Center"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: ""

, "Should the contract number be set manually or be auto-created?"
: ""

, "automatically"
: ""

, "manually"
: ""

, "Contract Number Validation"
: ""

, "The Number can be validated as text or number."
: ""

, "Text"
: ""

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""

, "manage products"
: ""

, "add, edit and delete products"
: ""

, "manage contracts"
: ""

, "add, edit and delete contracts"
: ""

, "manage cost centers"
: ""

, "add, edit and delete cost centers"
: ""

, "manage customers"
: ""

, "add, edit and delete customers"
: ""

, "manage suppliers"
: ""

, "add, edit and delete suppliers"
: ""

, "manage invoices"
: ""

, "add, edit and delete invoices"
: ""

, "manage divisions"
: ""

, "add, edit and delete divisions"
: ""

, "manage order confirmations"
: ""

, "add, edit and delete order confirmations"
: ""

, "manage offers"
: ""

, "add, edit and delete offers"
: ""

, "manage purchase invoices"
: ""

, "add, edit and delete purchase invoices"
: ""

, "change number of an order confirmations"
: ""

, "allow to change the number of an order confirmation on update"
: ""

, "set number of invoices"
: ""

, "allow to set the number of an invoice"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "You do not have admin rights on Sales"
: ""

, "The number you have tried to set is already in use!"
: ""

, "My Products"
: ""

, "Products created by me"
: ""

, "My Contracts"
: ""

, "Contracts created by myself"
: ""

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "Products created by myself"
: ""

, "Status"
: ""

, "Cleared In"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "You have to set a customer!"
: ""

, "Taxes (VAT)"
: ""

, "VAT ID"
: ""

, "Selected  {0}"
: ""

, "Add New Billing Address"
: ""

, "Add New Delivery Address"
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "Add, edit and delete invoices."
: ""

, "Manage Divisions"
: ""

, "Add, edit and delete divisions."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""

, "Customer"
: ""

, "Invoice Position"
: ""

, "Offer"
: ""

, "Order Confirmation"
: ""

, "Product"
: ""

, "Contract"
: ""

, "Invoice"
: ""

, "Address"
: ""

, "Cost Center"
: ""

, "Supplier"
: ""

, "Division"
: ""

, "Purchase Invoice"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Sales/js/Sales-lang-ja_JP-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (Japan) (http://www.transifex.com/tine20/tine20/language/ja_JP/)\nLanguage: ja_JP\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Either postalcode or postbox is required!"
: ""

, "Copy Supplier"
: ""

, "Add New Supplier"
: ""

, "Edit Supplier \"{0}\""
: ""

, "Copy address to the clipboard"
: ""

, "Supplier, Suppliers"
: [
  ""

]
, "Core Data"
: ""

, "Supplier Number"
: ""

, "Name"
: ""

, "Contact Person (external)"
: ""

, "Contact Person (internal)"
: ""

, "Accounting"
: ""

, "VAT ID"
: ""

, "Credit Term (days)"
: ""

, "Currency"
: ""

, "Currency Translation Rate"
: ""

, "IBAN"
: ""

, "BIC"
: ""

, "Postal Address"
: ""

, "Street"
: ""

, "Postbox"
: ""

, "Postalcode"
: ""

, "Locality"
: ""

, "Region"
: ""

, "Country"
: ""

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Miscellaneous"
: ""

, "Web"
: ""

, "Description"
: ""

, "Enter description"
: ""

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: ""

, "Add New Invoice"
: ""

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: ""

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Price Net"
: ""

, "Taxes (VAT)"
: ""

, "Price Gross"
: ""

, "Sales Tax (percent)"
: ""

, "Inventory Change"
: ""

, "Invoice, Invoices"
: [
  ""

]
, "Invoice Number"
: ""

, "automatically set..."
: ""

, "Date"
: ""

, "Type"
: ""

, "Contract, Contracts"
: [
  ""

]
, "Customer, Customers"
: [
  ""

]
, "Billing Address"
: ""

, "Credit Term"
: ""

, "Cleared"
: ""

, "Interval Begins"
: ""

, "Interval Ends"
: ""

, "Select invoice"
: ""

, "Total Price"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Loading..."
: ""

, "Euro (€)"
: ""

, "Order Confirmation, Order Confirmations"
: [
  ""

]
, "without order confirmation"
: ""

, "Number"
: ""

, "Title"
: ""

, "Billing Addresses"
: ""

, "Delivery Address"
: ""

, "Delivery Addresses"
: ""

, "Edit {0} \"{1}\""
: ""

, "Add New Billing Address"
: ""

, "Add New Delivery Address"
: ""

, "Apply postal address"
: ""

, "Number Debit"
: ""

, "Address, Addresss"
: [
  ""

]
, "without customer"
: ""

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Date of invoice"
: ""

, "Due in"
: ""

, "Due date"
: ""

, "Additional Price Gross"
: ""

, "Discount (%)"
: ""

, "Purchase Invoice, Purchase Invoices"
: [
  ""

]
, "Overdue date"
: ""

, "Discount until"
: ""

, "Dun date"
: ""

, "Payed at"
: ""

, "Method of payment"
: ""

, "Approver"
: ""

, "Lead Cost Center"
: ""

, "Add New Offer"
: ""

, "Clipboard"
: ""

, "Product, Products"
: [
  ""

]
, "Quantity"
: ""

, "Interval"
: ""

, "Billing Point"
: ""

, "begin"
: ""

, "end"
: ""

, "Start Date"
: ""

, "End Date"
: ""

, "Attributes"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "without contract"
: ""

, "Add New Order Confirmation"
: ""

, "Offer, Offers"
: [
  ""

]
, "Add New Product"
: ""

, "Product Number"
: ""

, "GTIN"
: ""

, "Category"
: ""

, "Manufacturer"
: ""

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Enter description..."
: ""

, "Accountable"
: ""

, "Selected  {0}"
: ""

, "Select customer"
: ""

, "Customer Number"
: ""

, "Products"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "Select supplier"
: ""

, "Add New Cost Center"
: ""

, "Remark"
: ""

, "without supplier"
: ""

, "Add New Division"
: ""

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "Either street or postbox is required!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "Name shorthand"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: ""

, "Positions"
: ""

, "Ok"
: ""

, "Export Records from these Positions"
: ""

, "without approver"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: ""

, "Should the contract number be set manually or be auto-created?"
: ""

, "automatically"
: ""

, "manually"
: ""

, "Contract Number Validation"
: ""

, "The Number can be validated as text or number."
: ""

, "Text"
: ""

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: ""

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: ""

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: ""

, "EC card"
: ""

, "Paypal"
: ""

, "Assets"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: ""

, "cleared"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: ""

, "Purchase Invoice Module"
: ""

, "You do not have admin rights on Sales"
: ""

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "Invoice Timesheet"
: ""

, "CLEARED"
: ""

, "INVOICE"
: ""

, "GENDER_Cost Center"
: ""

, "Cost Center, Cost Centers"
: [
  ""

]
, "GENDER_Offer"
: ""

, "GENDER_Invoice"
: ""

, "Sales Tax"
: ""

, "Reversal Invoice"
: ""

, "Invoice Item"
: ""

, "Is active"
: ""

, "GENDER_Contract"
: ""

, "Merge"
: ""

, "Responsible"
: ""

, "Partner"
: ""

, "Time Account"
: ""

, "GENDER_Customer)recordsName"
: ""

, "GENDER_Order Confirmation"
: ""

, "GENDER_Supplier"
: ""

, "GENDER_Division"
: ""

, "Division, Divisions"
: [
  ""

]
, "Billing Interval"
: ""

, "Piece"
: ""

, "GENDER_Address"
: ""

, "Due at"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""

]
, "Month"
: ""

, "Unit"
: ""

, "The number you have tried to set is already in use!"
: ""

, "My Products"
: ""

, "Products created by me"
: ""

, "My Contracts"
: ""

, "Contracts created by myself"
: ""

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "All Suppliers"
: ""

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: ""

, "All product records"
: ""

, "All Contracts"
: ""

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "You have to set a customer!"
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "manage invoices"
: ""

, "Add, edit and delete invoices."
: ""

, "Manage Divisions"
: ""

, "Add, edit and delete divisions."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""

, "Supplier"
: ""

, "Invoice"
: ""

, "Contract"
: ""

, "Customer"
: ""

, "Order Confirmation"
: ""

, "Address"
: ""

, "Purchase Invoice"
: ""

, "Product"
: ""

, "Offer"
: ""

, "Cost Center"
: ""

, "Division"
: ""

, "Invoice Position"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
